fn pick_scenario(request: &MockRequest) -> Option<&'static Scenario>Expand description
The scenario that answers request, or None when the mock answers nothing like it.
fn pick_scenario(request: &MockRequest) -> Option<&'static Scenario>The scenario that answers request, or None when the mock answers nothing like it.