fn response_object(response_id: &str) -> ValueExpand description
The response object of a lifecycle event before the last one. Only id and a possible error
are read by the chatbot; Azure sends the full request parameters here as well. See
completed_response_object for the terminal event.